# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "Example: Nice DiffEq Syntax Without A DSL" => "Example_dsl.md",
    "SLArrays" => "SLArrays.md",
    "LArrays" => "LArrays.md",
    "Relation to NamedTuples" => "NamedTuples_relation.md",
    "Note: Labelled Slices" => "Note_labelled_slices.md",
]
